# GUI应用程序主程序
import sys

from PyQt5.QtCore import QSystemSemaphore, QSharedMemory, QTranslator
from PyQt5.QtGui import QIcon
from PyQt5.QtWidgets import QApplication

from src.config import configure
from src.const.const import sys_const
from src.controller.myFrame import QmyFrame
from src.controller.myMessageBox import QmyMessageBox
from src.exception.MyException import myExcepthook
from src.lib.gifSplashScreen import GifSplashScreen
from src.lib.myFramelessQWidget import FramelessWindow
from src.message.message import W0002
from src.module import logHelper

# 样式
StyleSheet = """
/*标题栏*/
TitleBar {
    background-color: #efefef;
}
/*最小化最大化关闭按钮通用默认背景*/
#buttonMinimum,#buttonMaximum,#buttonClose {
    border: none;
    background-color: #efefef;
}
/*悬停*/
#buttonMinimum:hover,#buttonMaximum:hover {
    background-color: white;
    color: red;
}
#buttonClose:hover {
    color: red;
}
/*鼠标按下不放*/
#buttonMinimum:pressed,#buttonMaximum:pressed {
    background-color: #ffc1c1;
}
#buttonClose:pressed {
    color: red;
    background-color: #ffc1c1;
}

"""

sys.excepthook = myExcepthook

logs = logHelper.logger.getLogger(__name__)
logs.info("启动应用程序")
app = QApplication(sys.argv)  # 创建GUI应用程序
app.setStyleSheet(StyleSheet)

# 汉化
translator = QTranslator()
translator.load('./i18n/qm/qt_zh_CN.qm')
app.installTranslator(translator)

# 创建信号量
semaphore = QSystemSemaphore("SingleAppTest2Semaphore", 1);
# 启用信号量，禁止其他实例通过共享内存一起工作
semaphore.acquire();

# 在linux / unix
# 程序异常结束共享内存不会回收
# 在这里需要提供释放内存的接口，就是在程序运行的时候如果有这段内存先清除掉
nix_fix_shared_memory = QSharedMemory("SingleAppTest2");
if nix_fix_shared_memory.attach():
    nix_fix_shared_memory.detach();

# 创建一个共享内存  “SingleAppTest2”表示一段内存的标识key 可作为唯一程序的标识
sharedMemory = QSharedMemory("SingleAppTest2");
# 测试是否已经运行
isRunning = False;
# 试图将共享内存的副本附加到现有的段中。
if sharedMemory.attach():
    # 如果成功，则确定已经存在运行实例
    isRunning = True;
else:
    # 否则申请一字节内存
    sharedMemory.create(1);
    # 确定不存在运行实例
    isRunning = False;
semaphore.release();

# 如果您已经运行了应用程序的一个实例，那么我们将通知用户。
if isRunning:
    QmyMessageBox.information(None, configure.question_page_title, W0002,
                                    QmyMessageBox.OK)
    sys.exit()
splash = GifSplashScreen('start_image.png')
splash.show()
mainWnd = FramelessWindow()
mainWnd.setWindowTitle(configure.title)
mainWnd.setWindowIcon(QIcon(sys_const.WEATHER_LOGO_PATH))
mainWnd.setWidget(QmyFrame(mainWnd))  # 把自己的窗口添加进来

# 重新设置大小
desktop = QApplication.desktop()  # 取得显示器对象
screenRect = desktop.screenGeometry()  # 取得屏幕大小
height = screenRect.height() / 2  # 取屏幕高的一半作为高
width = screenRect.width() / 2  # 取屏幕宽的一半作为宽
mainWnd.resize(width, height)  # 重新设置大小

mainWnd.show()
app.processEvents()
splash.close()
sys.exit(app.exec_())